Three sets of example vector data for Slovenia. Two sp objects and one matrix object. Chosen to match the "MODIS_SI_ds" raster data.
SI_positionsA list of three sets of example vector data:
A matrix of coordinates corresponding to the coordinates of two points in Slovenia. Manually created. MODIS sinusoidal projection.
SpatialPointsDataFrame of four points in Slovenian municipalities. Manually created. MODIS sinusoidal projection.
SpatialPolygonsDataFrame of three polygons corresponding to borders of municipalities. Acquired from GADM. MODIS sinusoidal projection.