numeric, a vector of values to be set to NA before the masking.
verbose
(Optional) logical. If TRUE outputs progress. Default is FALSE.
...
additional arguments to be passed on to approxNA. Of particular interest is the rule argument which defines how first and last cells are dealt with.
Value
A list of rasters with NAs filled.
Details
Loads all layers of a specific bands into a stack and uses approxNA to fill the NAs if possible. Note that the procedure requires the entire list of raster layery for each band to be be stacked. It is therefore very memory intensive and likely to fail for very large time series.
# NOT RUN {#Setup library(rtsVis)
x_list <- MODIS_SI_ds[seq(1,length(MODIS_SI_ds),15)] #A list of raster objects#Fill NAsx_list_filled <- ts_fill_na(x_list)
# }